
# madan
--------
![PyPI](https://img.shields.io/pypi/v/madan)

Madan is an end-to-end open source platform for math,machine learning,Computer Vision, and Natural Language Processing. It has a comprehensive, flexible ecosystem of tools, libraries, and community resources that lets researchers push the state-of-the-art in AI and developers easily build and deploy AI-powered applications.

<!-- Example  : One function that computes the object detection, depth of the object, face recognition, and object tracking.
<img src="/madanlibrarydemo.gif" alt="GitHub badge" /> -->


# Table of content
## 1. [Math](https://github.com/MadanBaduwal/ai_library/tree/master/madan/math)
## 2. [Machine learning](https://github.com/MadanBaduwal/ai_library/tree/master/madan/ml)
## 3. [Computer Vision](https://github.com/MadanBaduwal/ai_library/tree/master/madan/cv)
## 5. [Natural Language Processing](https://github.com/MadanBaduwal/ai_library/tree/master/madan/nlp)
-------
## Install

To install the current release
```shell
$ pip install madan
```
<img src="/madaninstalldemo.gif" alt="GitHub badge" />

To update madan to the latest version, add --upgrade flag to the above commands.





